local gr, floor = love.graphics, math.floor

function love.load()
	imgmap	= love.image.newImageData( 'map.png' )
	wx, wy	= imgmap:getWidth(), imgmap:getHeight()
	love.window.setMode( wx, wy,{ borderless = true } )
	bat		= {
		image	= gr.newImage( 'bat.png' ),
		x		= 55,
		y		= 102,
		width	= 10,
		height	= 10,
		dir		= 'right',
		sel		= 1,
		sound	= love.audio.newSource( 'sonar.wav' )
		}
	love.audio.setVolume(.2)
	for i = 1, 12 do
		bat[i]	= gr.newQuad( 32*(i-1),64,32,32, bat.image:getWidth(), bat.image:getHeight() )
		end
	tick		= 0
	radius		= 0
	end

function love.update( dt )

	radius = radius + dt * 200
	if radius >= 100 then radius = 0
		end

	if love.keyboard.isDown("left") then
		bat.x = bat.x - dt * 100
		bat.dir = 'left'
		end
	if love.keyboard.isDown("right") then
		bat.x = bat.x + dt * 100
		bat.dir = 'right'
		end
	if love.keyboard.isDown("up") then
		bat.y = bat.y - dt * 100
		bat.dir = 'up'
		end
	if love.keyboard.isDown("down")then
		bat.y = bat.y + dt * 100
		bat.dir = 'down'
		end

	local r, g, b, a = imgmap:getPixel( bat.x, bat.y )
	if r == 0 and g == 0 and b == 0 then
		bat.x, bat.y = 55, 102
		elseif r == 255 and g == 0 and b == 0 then
		love.event.quit()
		end

	tick = tick + dt		-- time delay for sound
	if tick > 0.15 then
		tick		= 0
		bat.sel	= bat.sel < 12 and bat.sel + 1 or 1
		love.audio.play( bat.sound )
		end
	end

function drawpoint( x, y )
	if (x < 1) or (x >= wx - 1) or (y < 1) or (y >= wy - 1) then
		else
		gr.setColor( imgmap:getPixel( x, y ) )
		gr.point( x, y)
		end
	end

function love.draw()
	local x0 = bat.x
	local y0 = bat.y

	local x = radius
	local y = 0
	local radiuserr = 1 - x

	while( x >= y ) do
		drawpoint( x + x0, y + y0)
		drawpoint( y + x0, x + y0)
		drawpoint(-x + x0, y + y0)
		drawpoint(-y + x0, x + y0)
		drawpoint(-x + x0,-y + y0)
		drawpoint(-y + x0,-x + y0)
		drawpoint( x + x0,-y + y0)
		drawpoint( y + x0,-x + y0)

		y = y + 1

		if radiuserr < 0 then
			radiuserr = radiuserr + 2 * y + 1
			else
			x = x - 1
			radiuserr = radiuserr + 2 * ( y - x + 1 )
			end
		if bat.dir == 'right' then
				gr.draw( bat.image,bat[bat.sel],floor(bat.x),floor(bat.y),0, 1, 1,16,16 )
			elseif bat.dir == 'left' then
				gr.draw( bat.image,bat[bat.sel],floor(bat.x),floor(bat.y),0,-1, 1,16,16 )
			elseif bat.dir == 'down' then
				gr.draw( bat.image,bat[bat.sel],floor(bat.x),floor(bat.y),0,-1,-1,16,16 )
			else
				gr.draw( bat.image,bat[bat.sel],floor(bat.x),floor(bat.y),0, 1, 1,16,16 )
			end
		end
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.quit() 	end
	end
